using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;

namespace InterfazRehabilitacion
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    /// 
    public class Game2 : Microsoft.Xna.Framework.Game
    {

        public Control2 form2;
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        Model myModel;
        float aspectRatio;

        SpriteFont spriteFont;

        Vector3 modelPosition = Vector3.Zero;
        float modelRotationY = 0.0f;
        float modelRotationX = 0.0f;
        float modelRotationZ = 0.0f;

        Vector3 cameraPosition = new Vector3(0.0f, 50.0f, 5000.0f);

        public Game2(Control2 form)
        {
            this.form2 = form;
            graphics = new GraphicsDeviceManager(this);
            graphics.PreferredBackBufferWidth = 800;
            graphics.PreferredBackBufferHeight = 600;
            Content.RootDirectory = "Content";
        }


        public Game2()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            // TODO: Add your initialization logic here

            base.Initialize();
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        /// 



        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);
            spriteFont = Content.Load<SpriteFont>("SpriteFont1");

            myModel = Content.Load<Model>("Models\\p1_wedge");
            aspectRatio = graphics.GraphicsDevice.Viewport.AspectRatio;
            
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            modelRotationX = (form2.roll*MathHelper.Pi/180)*2;
            modelRotationZ = (form2.pitch*MathHelper.Pi/180)*2;

          
            if(Keyboard.GetState().IsKeyDown(Keys.A))
                modelRotationY += MathHelper.ToRadians(1.0f);
            if (Keyboard.GetState().IsKeyDown(Keys.S))
                modelRotationY -= MathHelper.ToRadians(1.0f);

            if (Keyboard.GetState().IsKeyDown(Keys.Up))
                modelRotationX += MathHelper.ToRadians(1.0f);
            if (Keyboard.GetState().IsKeyDown(Keys.Down))
                modelRotationX -= MathHelper.ToRadians(1.0f);

            if (Keyboard.GetState().IsKeyDown(Keys.Left))
                modelRotationZ += MathHelper.ToRadians(1.0f);
            if (Keyboard.GetState().IsKeyDown(Keys.Right))
                modelRotationZ -= MathHelper.ToRadians(1.0f);

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);
                        
            Matrix[] transforms = new Matrix[myModel.Bones.Count];
            myModel.CopyAbsoluteBoneTransformsTo(transforms);

            foreach (ModelMesh mesh in myModel.Meshes)
            {
                foreach (BasicEffect effect in mesh.Effects)
                {
                    effect.EnableDefaultLighting();
                    effect.World = transforms[mesh.ParentBone.Index] *
                       Matrix.CreateRotationY(modelRotationY)*
                       Matrix.CreateRotationX(modelRotationX) *
                       Matrix.CreateRotationZ(modelRotationZ) *
                       Matrix.CreateTranslation(modelPosition);
                    effect.View = Matrix.CreateLookAt(cameraPosition, Vector3.Zero, Vector3.Up);
                    effect.Projection = Matrix.CreatePerspectiveFieldOfView(MathHelper.ToRadians(45.0f), aspectRatio, 1.0f, 10000.0f);
                
                }
                mesh.Draw();
            }

            spriteBatch.Begin();
            spriteBatch.DrawString(spriteFont, "Pitch:" + modelRotationX + ", Roll:" + modelRotationX + ", Yaw:" + modelRotationZ, new Vector2(100, 60), Color.White);
            spriteBatch.End();



            base.Draw(gameTime);
        }
    }
}
